"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const rehype_format_1 = __importDefault(require("rehype-format"));
const rehype_shiki_1 = __importDefault(require("rehype-shiki"));
const rehype_stringify_1 = __importDefault(require("rehype-stringify"));
const remark_parse_1 = __importDefault(require("remark-parse"));
const remark_rehype_1 = __importDefault(require("remark-rehype"));
const unified_1 = __importDefault(require("unified"));
const yaml_1 = __importDefault(require("yaml"));
function parse(content) {
    return new Promise(function (resolve, reject) {
        unified_1.default()
            .use(remark_parse_1.default)
            .use(remark_rehype_1.default)
            .use(rehype_format_1.default)
            .use(rehype_stringify_1.default)
            .use(rehype_shiki_1.default, { theme: 'Material-Theme-Ocean' })
            .process(content, function (err, file) {
            err ? reject(err) : resolve(String(file));
        });
    });
}
async function compile(filepath) {
    const data = yaml_1.default.parse(fs_1.default.readFileSync(filepath).toString('utf-8'));
    for (const { key, value, parent } of traverse(data)) {
        if (key === 'x-md-description') {
            delete parent['x-md-description'];
            parent['x-intellij-html-description'] = await parse(value);
        }
    }
    return JSON.stringify(data, null, 2);
}
exports.default = compile;
function* traverse(o, path = []) {
    for (const i in o) {
        const itemPath = path.concat(i);
        yield { key: i, value: o[i], path: itemPath, parent: o };
        if (o[i] !== null && typeof o[i] == 'object') {
            const child = o[i];
            //going one step down in the object tree!!
            yield* traverse(child, itemPath);
        }
    }
}
